;
;	>>> SV2K17 Invitro - Main Loop by JAC! <<<
;
;	Created for Sillyventure 2017 in Gdansk.
;
;	@com.wudsn.ide.asm.hardware=ATARI2600
;	@com.wudsn.ide.asm.mainsourcefile=SV2K17.asm

;===============================================================

	.proc main

	.proc reset		;Start of the main part
	cld
	ldx #0
	txa
clear	dex
	txs
	pha
	bne clear		;SP=$FF, X = A = 0, Y = undefined
	.endp			;End of reset

	jsr effect.sound.init
	jsr stage.init

;===============================================================

	.proc frame_loop
	
	.proc check_keys
	lda swchb
	lsr			;RESET (F2) pressed?
	bcc reset		;Yes, reset
	lsr			;SELECT (F1) pressed?
	bcs no_select		;No
is_select
	lda swchb		;SELECT (F1) released again?
	and #2
	beq is_select
	jsr stage.init_next	;Yes, enter next stage
	
no_select
	.endp

	jsr vsync_area

;===============================================================

	.proc vblank_area
	ldx #85			;PAL value
	jsr check_ntsc_60hz
	smi
	ldx #84-19		;NTSC value
	stx tim64t		;VBLANK time counter

	ldx stage_cnt
	mwa stage.stages.vblank,x animate_ptr
	jsr common.call_animate

sync	lda intim		;Sync with beam again
;	sta colubk		;Debug remaining time
stop	bmi stop		;Time overrun
	bne sync
	jsr bar
	lda #0
	jsr bar.store
	.endp			;End of vblank_area

;===============================================================

	.proc playfield_area

	lda stage_cnt
	and #$7f
	tax
	mwa stage.stages.playfield,x animate_ptr
	jsr common.call_animate
	jsr screen_off.with_sync

	sta wsync			;Special padding

	jsr bar.white
not_first_pattern
	lda #4
	jsr bar.store
	.endp				;End of playfield_area

;===============================================================

	.proc overscan_area

	ldx #81				;PAL value
	jsr check_ntsc_60hz
	smi
	ldx #81-39			;NTSC value
	stx tim64t			;Overscan time counter

	cli				;Clear pattern changed flag (I)
	jsr effect.sound.player		;Play sound
	php				;Check pattern changed flag (I)
	pla
	and #$4
	beq no_new_pattern

	lda effect.sound.tt_cur_pat_index_c0
	cmp #9
	bne no_next_stage
	lda stage_cnt
	bne no_next_stage
	jsr stage.init_next

no_next_stage
no_new_pattern

	lda stage_cnt
	bpl no_stage_end
	and #$7f
	sta stage_cnt
	jsr stage.init_next
no_stage_end

sync	lda intim			;Sync with beam again
	.if .def strict_mode		;Check for time overrun in strict mode
stop	bmi stop			;Time overrun occurred, so stop here
	.endif
	bne sync
	jmp frame_loop
	.endp				;End of overscan_area

	.proc check_ntsc_60hz		;IN: SWCHB, OUT: <N>=1 for PAL
	lda swchb			;D3 color - B/W 0 = B/W, 1 = color
	asl
	asl
	asl
	eor swchb			;D6 P0 difficulty 0 = amateur (B, F6), 1 = pro (A, F5)
	asl
	rts
	.endp

;===============================================================

	.proc vsync_area
	lda #$0e			;Create 3 lines of vsync=1 plus 1 line of vsync=0
	sta vblank			;Activate VBLANK bit 1 in scanline 308
loop
	sta wsync
	sta vsync
	lsr
	bne loop
	sta vblank			;Deactivate VBLANK bit 1 in scanline 0
	rts
	.endp				;End of vsync_area

;===============================================================

	.endp				;End of frame_loop

;===============================================================

	.proc stage
	
	.proc init_next
	ldx stage_cnt			;Initialize next stage, IN: stage_cnt
	inx
	inx
	stx stage_cnt
	cpx #[.len stages]
	bne not_last_stage
	ldx #2				;Restart at 2nd stage, not a intro

not_last_stage
	stx stage_cnt
	.endp				;Fall through

	.proc init			;Initialize current stage, IN: stage_cnt
	ldx stage_cnt
again	mwa stages.init,x animate_ptr
	jmp common.call_animate

	.endp				;End of init

	.local stages			;List of INIT, PLAYFIELD and VBLANK routines
	.use bank0
	.use bank1
	.use bank2
	.use bank3

	.local init
	.word effect.rink.init
	.word effect.scroll.init.phase1
	.word effect.logo.init.phase1
	.word effect.scroll.init.phase2
	.word effect.logo.init.phase2
	.word effect.scroll.init.phase3
	.word effect.logo.init.phase3
	.word effect.scroll.init.phase4
	.word effect.logo.init.phase4
	.word effect.scroll.init.phase5
	.word effect.logo.init.phase4
	.endl

	.local playfield
	.word effect.rink.playfield
	.word effect.scroll.playfield
	.word effect.logo.playfield
	.word effect.scroll.playfield
	.word effect.logo.playfield
	.word effect.scroll.playfield
	.word effect.logo.playfield
	.word effect.scroll.playfield
	.word effect.logo.playfield
	.word effect.scroll.playfield
	.word effect.logo.playfield
	.endl

	.local vblank
	.word effect.rink.vblank
	.word effect.scroll.vblank
	.word effect.logo.vblank
	.word effect.scroll.vblank
	.word effect.logo.vblank
	.word effect.scroll.vblank
	.word effect.logo.vblank
	.word effect.scroll.vblank
	.word effect.logo.vblank
	.word effect.scroll.vblank
	.word effect.logo.vblank
	.endl

	.endl				;End of stages

	
;===============================================================

	.proc stop			;Stop and show blank screen at 50 FPS

	delay_cnt = $80

	lda #0
	tax
clear	sta $00,x
	inx
	bne clear

kernel	jsr main.frame_loop.vsync_area
	ldx #308/2
loop	sta wsync
	sta wsync
	dex
	bne loop
	lsr swchb			;Reset pressed?
	bcc restart			;Yes, reset
	inw delay_cnt
	lda delay_cnt+1
	cmp #2				;Wait 2*$100/50=10,24s	
	bne kernel
restart	jmp ($fffc)
	.endp				;End of stop
	
	.endp

;===============================================================

	.proc bar			;Create a horizontal white bar
white	lda #14
store	sta wsync			;External entry point to save space for differently colored bar
	sta colubk
	rts
	.endp				;End of bar

;===============================================================

	.proc screen_off		;Turn the screen off
with_sync
	sta wsync
without_sync
	lda #0
	sta colubk
	sta pf0
	sta pf1
	sta pf2
	sta grp0
	sta grp1
	sta enam0
	sta enam1
	sta enabl
	sta colup0
	sta colup1
	sta colupf
	rts
	.endp				;End of screen_off

	.endp				;End of main
	