package com.wudsn.productions.atari2600.sv2k17;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.ScrollPane;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;
import java.awt.image.BufferedImage;
import java.util.ArrayList;
import java.util.List;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;

/**
 * Base class for source/binary generators.
 * 
 * @author Peter Dell
 * 
 */
public abstract class AbstractGenerator {
    private JFrame mainFrame;
    private BufferedImage bufferdImage;
    protected Graphics2D graphics;
    private JLabel imageLabel;

    protected String[] args;

    protected AbstractGenerator() {
    }

    protected final void createGraphics(int width, int height) {
	bufferdImage = new BufferedImage(width, height, BufferedImage.TYPE_INT_RGB);
	graphics = bufferdImage.createGraphics();
	graphics.setColor(Color.black);
	graphics.setBackground(Color.white);
	graphics.clearRect(0, 0, width, height);

	imageLabel = new JLabel(new ImageIcon(bufferdImage));
	ScrollPane scrollPane = new ScrollPane(ScrollPane.SCROLLBARS_ALWAYS);
	scrollPane.add(imageLabel);
	mainFrame = new JFrame(getClass().getName());
	mainFrame.add(scrollPane);
	mainFrame.pack();
	mainFrame.setVisible(true);

	Dimension screenSize = java.awt.Toolkit.getDefaultToolkit().getScreenSize();
	width = Math.min(width, screenSize.width) + 32;
	height = Math.min(height, screenSize.height) + 48;
	mainFrame.setSize(width, height);
	mainFrame.addWindowListener(new WindowListener() {

	    @Override
	    public void windowOpened(WindowEvent windowevent) {
	    }

	    @Override
	    public void windowIconified(WindowEvent windowevent) {
	    }

	    @Override
	    public void windowDeiconified(WindowEvent windowevent) {
	    }

	    @Override
	    public void windowDeactivated(WindowEvent windowevent) {
	    }

	    @Override
	    public void windowClosing(WindowEvent windowevent) {
		System.exit(1);
	    }

	    @Override
	    public void windowClosed(WindowEvent windowevent) {
	    }

	    @Override
	    public void windowActivated(WindowEvent windowevent) {
	    }
	});
    }

    protected abstract void run();

    protected final List<Integer> asList(int[] array) {
	List<Integer> result = new ArrayList<Integer>();
	for (int j = 0; j < array.length; j++) {
	    result.add(Integer.valueOf(array[j]));
	}
	return result;
    }

    protected final void printArray(String name, List<Integer> array, int lineSize) {
	if (name == null) {
	    throw new IllegalArgumentException("Parameter 'name' must not be null.");
	}
	if (array == null) {
	    throw new IllegalArgumentException("Parameter 'array' must not be null.");
	}
	System.out.print(name + "\t" + ".byte ");
	for (int i = 0; i < array.size(); i++) {
	    System.out.print(array.get(i));
	    if (lineSize > 0 && i > 0 && (i % lineSize) == 0) {
		System.out.print("\t" + ".byte ");
	    }
	    if (i < array.size() - 1) {
		System.out.print(",");
	    }
	}
	System.out.println();
    }

    protected final void println() {
	System.out.println();
    }

    protected final void println(Object o) {
	System.out.println(o);
    }

    protected final void printArrayHex(String name, List<Integer> array, int lineSize) {
	if (name == null) {
	    throw new IllegalArgumentException("Parameter 'name' must not be null.");
	}
	if (array == null) {
	    throw new IllegalArgumentException("Parameter 'array' must not be null.");
	}
	System.out.print(name + "\t" + ".byte ");
	for (int i = 0; i < array.size(); i++) {
	    if (lineSize > 0 && i > 0 && (i % lineSize) == 0) {
		System.out.print("\t" + ".byte ");
	    }
	    System.out.print("$" + Integer.toHexString(array.get(i).intValue()));
	    if (i < array.size() - 1) {
		System.out.print(",");
	    }
	}
	println();
    }

    public static void main(Class<? extends AbstractGenerator> clazz, String[] args) {
	if (clazz == null) {
	    throw new IllegalArgumentException("Parameter 'clazz' must not be null.");
	}
	if (args == null) {
	    throw new IllegalArgumentException("Parameter 'args' must not be null.");
	}
	try {
	    AbstractGenerator instance = clazz.newInstance();
	    instance.args = args;
	    instance.run();
	} catch (InstantiationException ex) {
	    throw new RuntimeException(ex);
	} catch (IllegalAccessException ex) {
	    throw new RuntimeException(ex);
	}

    }
}
